define(
//begin v1.x content
({
	insertAnchor: "アンカーの挿入",
	title: "アンカー・プロパティー",
	anchor: "名前:",
	text: "説明:",
	set: "設定",
	cancel: "キャンセル"
})
//end v1.x content
);
